@@ -405,6 +405,27 @@ func TestAzureMonitorParseResponse(t *testing.T) {
 						&data.FieldConfig{Unit: "decbytes", DisplayName: "danieltest {Blob Type=Azure Data Lake Storage, Tier=Cool}"})),
 			},
 		},
+		{
+			name:         "unspecified unit with alias should not panic",
+			responseFile: "8-azure-monitor-response-unspecified-unit.json",
+			mockQuery: &AzureMonitorQuery{
+				Alias: "custom",
+				UrlComponents: map[string]string{
+					"resourceName": "grafana",
+				},
+				Params: url.Values{
+					"aggregation": {"Average"},
+				},
+			},
+			expectedFrames: data.Frames{
+				data.NewFrame("",
+					data.NewField("", nil,
+						[]time.Time{time.Date(2019, 2, 8, 10, 13, 0, 0, time.UTC)}),
+					data.NewField("Percentage CPU", nil, []float64{
+						2.0875,
+					}).SetConfig(&data.FieldConfig{DisplayName: "custom"})),
+			},
+		},
 	}
 
 	datasource := &AzureMonitorDatasource{}
