@@ -16,8 +16,8 @@ import (
 	"github.com/grafana/grafana-plugin-sdk-go/experimental"
 	"github.com/xorcare/pointer"
 
-	influxdb2 "github.com/influxdata/influxdb-client-go"
-	"github.com/influxdata/influxdb-client-go/api"
+	influxdb2 "github.com/influxdata/influxdb-client-go/v2"
+	"github.com/influxdata/influxdb-client-go/v2/api"
 )
 
 //--------------------------------------------------------------
@@ -47,7 +47,7 @@ func (r *MockRunner) runQuery(ctx context.Context, q string) (*api.QueryTableRes
 	defer server.Close()
 
 	client := influxdb2.NewClient(server.URL, "a")
-	return client.QueryApi("x").Query(ctx, q)
+	return client.QueryAPI("x").Query(ctx, q)
 }
 
 func verifyGoldenResponse(name string) (*backend.DataResponse, error) {
@@ -55,7 +55,7 @@ func verifyGoldenResponse(name string) (*backend.DataResponse, error) {
 		testDataPath: name + ".csv",
 	}
 
-	dr := ExecuteQuery(context.Background(), QueryModel{MaxDataPoints: 100}, runner, 50)
+	dr := executeQuery(context.Background(), QueryModel{MaxDataPoints: 100}, runner, 50)
 	err := experimental.CheckGoldenDataResponse("./testdata/"+name+".golden.txt", &dr, true)
 	return &dr, err
 }
@@ -68,7 +68,7 @@ func TestExecuteSimple(t *testing.T) {
 			testDataPath: "simple.csv",
 		}
 
-		dr := ExecuteQuery(ctx, QueryModel{MaxDataPoints: 100}, runner, 50)
+		dr := executeQuery(ctx, QueryModel{MaxDataPoints: 100}, runner, 50)
 
 		if dr.Error != nil {
 			t.Fatal(dr.Error)
@@ -104,7 +104,7 @@ func TestExecuteMultiple(t *testing.T) {
 			testDataPath: "multiple.csv",
 		}
 
-		dr := ExecuteQuery(ctx, QueryModel{MaxDataPoints: 100}, runner, 50)
+		dr := executeQuery(ctx, QueryModel{MaxDataPoints: 100}, runner, 50)
 
 		if dr.Error != nil {
 			t.Fatal(dr.Error)
@@ -140,7 +140,7 @@ func TestExecuteGrouping(t *testing.T) {
 			testDataPath: "grouping.csv",
 		}
 
-		dr := ExecuteQuery(ctx, QueryModel{MaxDataPoints: 100}, runner, 50)
+		dr := executeQuery(ctx, QueryModel{MaxDataPoints: 100}, runner, 50)
 
 		if dr.Error != nil {
 			t.Fatal(dr.Error)
@@ -176,7 +176,7 @@ func TestAggregateGrouping(t *testing.T) {
 			testDataPath: "aggregate.csv",
 		}
 
-		dr := ExecuteQuery(ctx, QueryModel{MaxDataPoints: 100}, runner, 50)
+		dr := executeQuery(ctx, QueryModel{MaxDataPoints: 100}, runner, 50)
 		if dr.Error != nil {
 			t.Fatal(dr.Error)
 		}
@@ -229,7 +229,7 @@ func TestNonStandardTimeColumn(t *testing.T) {
 			testDataPath: "non_standard_time_column.csv",
 		}
 
-		dr := ExecuteQuery(ctx, QueryModel{MaxDataPoints: 100}, runner, 50)
+		dr := executeQuery(ctx, QueryModel{MaxDataPoints: 100}, runner, 50)
 		if dr.Error != nil {
 			t.Fatal(dr.Error)
 		}
@@ -274,7 +274,7 @@ func TestBuckets(t *testing.T) {
 			testDataPath: "buckets.csv",
 		}
 
-		dr := ExecuteQuery(ctx, QueryModel{MaxDataPoints: 100}, runner, 50)
+		dr := executeQuery(ctx, QueryModel{MaxDataPoints: 100}, runner, 50)
 
 		if dr.Error != nil {
 			t.Fatal(dr.Error)
