@@ -1,3 +1,4 @@
+import 'symbol-observable';
 import 'core-js/stable';
 import 'regenerator-runtime/runtime';
 
@@ -94,7 +95,7 @@ export class GrafanaApp {
 
     addClassIfNoOverlayScrollbar();
     setLocale(config.bootData.user.locale);
-    setTimeZoneResolver(() => config.bootData.user.timeZone);
+    setTimeZoneResolver(() => config.bootData.user.timezone);
 
     setMarkdownOptions({ sanitize: !config.disableSanitizeHtml });
 
