@@ -244,8 +244,7 @@ export function parseUrlState(initial: string | undefined): ExploreUrlState {
   };
   const datasource = parsed[ParseUrlStateIndex.Datasource];
   const parsedSegments = parsed.slice(ParseUrlStateIndex.SegmentsStart);
-  const metricProperties = ['expr', 'expression', 'target', 'datasource', 'query'];
-  const queries = parsedSegments.filter(segment => isSegment(segment, ...metricProperties));
+  const queries = parsedSegments.filter(segment => !isSegment(segment, 'ui', 'originPanelId'));
 
   const uiState = parsedSegments.filter(segment => isSegment(segment, 'ui'))[0];
   const ui = uiState
