@@ -17,7 +17,7 @@ export function PromExploreExtraField(props: PromExploreExtraFieldProps) {
   const { label, onChangeFunc, onKeyDownFunc, value, hasTooltip, tooltipContent } = props;
 
   return (
-    <div className="gf-form-inline explore-input--ml" aria-label="Prometheus extra field">
+    <div className="gf-form-inline" aria-label="Prometheus extra field">
       <div className="gf-form">
         <InlineFormLabel width={5} tooltip={hasTooltip ? tooltipContent : null}>
           {label}
